@@ -12,8 +12,11 @@ from .rules.pacing_type import PacingTypeRule
 from .rules.roi_target_rule import StrategyRoiTargetRule
 from .rules.strategy_dates import StrategyDatesRule
 from .rules.strategy_dates_required import StrategyDatesRequiredRule
+from .rules.strategy_frequency_type_for_pg import StrategyFrequencyTypeForPGRule
+from .rules.strategy_goal_types_for_pg import StrategyGoalTypesForPGRule
 from .rules.strategy_required_fields_post import StrategyPostRequiredFieldsRule
 from .rules.strategy_type_rule import StrategyTypeRule
+from .rules.strategy_use_optimization_for_pg import StrategyUseOptimizationForPGRule
 from .rules.t1_budget import T1BudgetRule
 from .. import T1Service
 from ..models.dto.campaign import CampaignDTO
@@ -66,6 +69,12 @@ class StrategyPostValidator(AbstractValidator):
         # strategy_type validation
         self.rules.append(StrategyTypeRule(strategy_type=dto.strategy_type))
 
+        # pg campaign custom rules
+        if campaign_dto.is_programmatic_guaranteed:
+            self.add_rule(StrategyGoalTypesForPGRule(goal_type=dto.goal_type))
+            self.add_rule(StrategyFrequencyTypeForPGRule(frequency_type=dto.frequency_type))
+            self.add_rule(StrategyUseOptimizationForPGRule(use_optimization=dto.use_optimization))
+
         # pacing_* validation
         self.rules.append(PacingTypeRule(pacing_type=dto.pacing_type,
                                          pacing_interval=dto.pacing_interval,
@@ -104,10 +113,6 @@ class StrategyPostValidator(AbstractValidator):
                                                                   "frequency_amount": "frequency_amount",
                                                                   "frequency_interval": "frequency_interval"}))
 
-        # goal_type should be one of ctr, vcr, viewability_rate, cpa, cpc, reach, roi, spend, vcpm
-        # goal_value Must be > 0 and <= 9,999,999.9999 if goal_type in (ROI, CPA, CPC, Viewable
-        # CPM, CPM Reach, CPM Spend)
-        # goal_value Must be > 0 and <= 100 if goal_type in (CTR, Video Completion Rate (VCR), Viewability Rate (VR))
         if dto.goal_type is not GoalTypeEnum.UNDEFINED:
             self.add_rule(GoalTypeRule(goal_type=dto.goal_type,
                                        goal_value=dto.goal_value))
